@@ -1,5 +1,5 @@
 try:
-    import io
+    """import io"""
     import os
     import sys
     import ctypes
@@ -18,7 +18,7 @@ try:
     import random
     from pathlib import Path
     from typing import (Tuple , Any)
-    from .Exceptions import (
+    from .exceptions import (
         AdminPermissionRequestDenied ,
         InvalidVariableType ,
         NoneTypeArgumentBool ,
@@ -27,6 +27,14 @@ try:
         UndefinedOperatingSystem ,
         UnrecognizeableTypeArgument
     )
+    from .validators import (
+        BooleanValidator ,
+        IntegerValidator ,
+        StringValidator ,
+        LengthValidator ,
+        LinuxOperatingSystemIdentifierValidator ,
+        WindowsOperatingSystemIdentifierValidator
+    )
     
     if (__name__ == '__main__' and __package__ is None):
         sys.path.append(os.path.dirname(p=os.path.dirname(p=os.path.abspath(path=__file__))))
@@ -46,107 +54,10 @@ except:
 
 
 
-class Version:
+class MetaData:
     """with io.open(file=os.path.join(os.path.abspath('.') , 'version.txt') , mode='r+' , encoding='utf-8' , errors=None) as v:
         __version__ = v.readline()"""
-    __version__ = '4.2.6'
-
-
-
-
-
-class OperatingSystem(object):
-    WINDOWS : bool
-    LINUX : bool
-
-
-
-
-
-# class PSTExceptions:
-#     class AdminPermissionRequestDenied(Exception):
-#         """ Set the Argument Variable 'show' to 'True' """
-#     class NoneTypeArgumentBool(Exception):
-#         """ The Variable For Argument 'show' Should be 'Boolean' Type """
-#     class NoneTypeArgumentInt(Exception):
-#         """ The Variable For Argument 'timeout' Should be 'Int' Type """
-#     class NoneTypeArgumentString(Exception):
-#         """ The Variable For Argument 'link' Should be 'String' Type """
-#     class UndefinedOperatingSystem(Exception):
-#         """ The Operating System is Not Defined Yet """
-#     class UnrecognizeableTypeArgument(Exception):
-#         """ The Variable For Arguments is not Recognizeable """
-#     class InvalidVariableType(Exception):
-#         """ The Variable Type Chosen is not The Correct One """
-        
-        
-
-
-
-
-class PSTValidators:
-    class LengthValidator:
-        def getSize(bytes , default = "B"):
-            for unit in ["" , "K" , "M" , "G" , "T" , "P"]:
-                if (bytes < 1024):
-                    return f"{bytes:.2f}{unit}{default}"
-                bytes /= 1024
-
-    class StringValidator:
-        def is_string(string):
-            if (type(string) is str):
-                return string
-            else:
-                return str(string)
-        
-    class BooleanValidator:
-        def is_boolean(boolean):
-            if (type(boolean) is bool):
-                return boolean
-            else:
-                try:
-                    return bool(boolean)
-                except TypeError:
-                    return 0
-
-    class IntegerValidator:
-        def is_integer(integer):
-            if (type(integer) is int):
-                return integer
-            else:
-                try:
-                    return int(integer)
-                except TypeError:
-                    return 0
-                
-    class LinuxOperatingSystemIdentifierValidator(OperatingSystem):
-        @classmethod
-        def is_linux(cls , lnx):
-            if (platform.system() == lnx):
-                cls.LINUX = True
-                cls.WINDOWS = False
-                return lnx
-            
-        @property
-        @classmethod
-        def current_is_linux(cls):
-            if (platform.system()[0].upper() == 'L'):
-                cls.LINUX = True
-                
-    class WindowsOperatingSystemIdentifierValidator(OperatingSystem):
-    
-        @classmethod
-        def is_windows(cls , win):
-            if (platform.system() == win):
-                cls.WINDOWS = True
-                cls.LINUX = False
-                return win
-            
-        @property
-        @classmethod
-        def current_is_windows(cls):
-            if (platform.system()[0].upper() == 'W'):
-                cls.WINDOWS = True
+    __version__ = '4.2.7'
 
 
 
@@ -170,7 +81,7 @@ class NetworkTools:
         Returns:
             str: _Local IP_
         """
-        if (PSTValidators.BooleanValidator.is_boolean(show)):
+        if (BooleanValidator.is_boolean(show)):
             if (show is True):
                 return cls.localIP
             elif (show is False):
@@ -190,7 +101,7 @@ class NetworkTools:
         Returns:
             str: _Public IP_
         """
-        if (PSTValidators.BooleanValidator.is_boolean(show)):
+        if (BooleanValidator.is_boolean(show)):
             if (show is True):
                 try:
                     return cls.publicIP
@@ -214,7 +125,7 @@ class NetworkTools:
         Returns:
             str: _MAC Address_
         """
-        if (PSTValidators.BooleanValidator.is_boolean([show , network_request])):
+        if (BooleanValidator.is_boolean([show , network_request])):
             if (show is True):
                 try:
                     return getmac.get_mac_address(ip = socket.gethostbyname(socket.gethostname()) , network_request = network_request)
@@ -237,7 +148,7 @@ class NetworkTools:
         Returns:
             str: _Shows Some of Your Network Information_
         """
-        if (PSTValidators.BooleanValidator.is_boolean(show)):
+        if (BooleanValidator.is_boolean(show)):
             if (show is True):
                 for interfaceName , interfaceAddresses in cls.ipAddrs.items():
                     for address in interfaceAddresses:
@@ -267,9 +178,9 @@ class NetworkTools:
         Returns:
             str: _Shows Saved Networks_
         """
-        if (PSTValidators.BooleanValidator.is_boolean(show)):
+        if (BooleanValidator.is_boolean(show)):
             if (show is True):
-                if (PSTValidators.WindowsOperatingSystemIdentifierValidator.current_is_windows):
+                if (WindowsOperatingSystemIdentifierValidator.current_is_windows):
                     for i in os.popen("netsh wlan show profiles"):
                         if ("All User Profile" in i):
                             i = str(i).split(":")
@@ -299,9 +210,9 @@ class NetworkTools:
         Returns:
             _str_: _Tests Internet Connection_
         """
-        if (PSTValidators.BooleanValidator.is_boolean(show)):
+        if (BooleanValidator.is_boolean(show)):
             if (show is True):
-                if (PSTValidators.IntegerValidator.is_integer(timeout)):
+                if (IntegerValidator.is_integer(timeout)):
                     try:
                         req = requests.get("https://www.google.com" , timeout = timeout)
                         return f"{colorama.ansi.Fore.GREEN}You're Connected To Internet"
@@ -327,9 +238,9 @@ class NetworkTools:
         Returns:
             _str_: Status Codes Available in Link or IP Address
         """
-        if (PSTValidators.BooleanValidator.is_boolean(show)):
+        if (BooleanValidator.is_boolean(show)):
             if (show is True):
-                if (PSTValidators.StringValidator.is_string(link)):
+                if (StringValidator.is_string(link)):
                     for code in range(200 , 599 + 1):
                         if (requests.get(link).status_code == code):
                             print(f"{colorama.ansi.Fore.MAGENTA}Status : {colorama.ansi.Fore.BLUE}{code} {colorama.ansi.Fore.GREEN}is Available")
@@ -382,7 +293,7 @@ class CPUTools:
         Returns:
             int: _CPU Physical Cores_
         """
-        if (PSTValidators.BooleanValidator.is_boolean(show)):
+        if (BooleanValidator.is_boolean(show)):
             if (show is True):
                 return cls.phCores
             elif (show is False):
@@ -402,7 +313,7 @@ class CPUTools:
         Returns:
             str: _CPU Total Cores_
         """
-        if (PSTValidators.BooleanValidator.is_boolean(show)):
+        if (BooleanValidator.is_boolean(show)):
             if (show is True):
                 return cls.totCores
             elif (show is False):
@@ -422,7 +333,7 @@ class CPUTools:
         Returns:
             float: _CPU Maximum Frequency_
         """
-        if (PSTValidators.BooleanValidator.is_boolean(show)):
+        if (BooleanValidator.is_boolean(show)):
             if (show is True):
                 return f"{cls.cpuFreq.max:.2f}Mhz"
             elif (show is False):
@@ -442,7 +353,7 @@ class CPUTools:
         Returns:
             float: _CPU Minimum Frequency_
         """
-        if (PSTValidators.BooleanValidator.is_boolean(show)):
+        if (BooleanValidator.is_boolean(show)):
             if (show is True):
                 return f"{cls.cpuFreq.min:.2f}Mhz"
             elif (show is False):
@@ -462,7 +373,7 @@ class CPUTools:
         Returns:
             float: _CPU Current Frequency_
         """
-        if (PSTValidators.BooleanValidator.is_boolean(show)):
+        if (BooleanValidator.is_boolean(show)):
             if (show is True):
                 return f"{cls.cpuFreq.current:.2f}Mhz"
             elif (show is False):
@@ -482,7 +393,7 @@ class CPUTools:
         Returns:
             float: _CPU Total Frequency_
         """
-        if (PSTValidators.BooleanValidator.is_boolean(show)):
+        if (BooleanValidator.is_boolean(show)):
             if (show is True):
                 return f"{psutil.cpu_percent()}%"
             elif (show is False):
@@ -502,7 +413,7 @@ class CPUTools:
         Returns:
             float: _CPU Usage Per Cores_
         """
-        if (PSTValidators.BooleanValidator.is_boolean(show)):
+        if (BooleanValidator.is_boolean(show)):
             if (show is True):
                 for core , percentage in enumerate(psutil.cpu_percent(percpu = True , interval = 1)):
                     print(f"Core {core} : {percentage}%")
@@ -531,7 +442,7 @@ class GPUTools:
         Returns:
             str: _GPU ID_
         """
-        if (PSTValidators.BooleanValidator.is_boolean(show)):
+        if (BooleanValidator.is_boolean(show)):
             if (show is True):
                 for gpu in cls.gpuInfo:
                     gpuID = gpu.id
@@ -553,7 +464,7 @@ class GPUTools:
         Returns:
             str: _GPU Name_
         """
-        if (PSTValidators.BooleanValidator.is_boolean(show)):
+        if (BooleanValidator.is_boolean(show)):
             if (show is True):
                 for gpu in cls.gpuInfo:
                     gpuName = gpu.name
@@ -575,7 +486,7 @@ class GPUTools:
         Returns:
             float: _GPU Load_
         """
-        if (PSTValidators.BooleanValidator.is_boolean(show)):
+        if (BooleanValidator.is_boolean(show)):
             if (show is True):
                 for gpu in cls.gpuInfo:
                     gpuLoad = gpu.load * 100
@@ -602,7 +513,7 @@ class GPUTools:
         Returns:
             float: _GPU Free Memory_
         """
-        if (PSTValidators.BooleanValidator.is_boolean(show)):
+        if (BooleanValidator.is_boolean(show)):
             if (show is True):
                 for gpu in cls.gpuInfo:
                     gpuFree = gpu.memoryFree
@@ -624,7 +535,7 @@ class GPUTools:
         Returns:
             float: _GPU Used Memory_
         """
-        if (PSTValidators.BooleanValidator.is_boolean(show)):
+        if (BooleanValidator.is_boolean(show)):
             if (show is True):
                 for gpu in cls.gpuInfo:
                     gpuUsed = f"{gpu.memoryUsed}MB"
@@ -646,7 +557,7 @@ class GPUTools:
         Returns:
             float: _GPU Total Memory_
         """
-        if (PSTValidators.BooleanValidator.is_boolean(show)):
+        if (BooleanValidator.is_boolean(show)):
             if (show is True):
                 for gpu in cls.gpuInfo:
                     gpuTot = f"{gpu.memoryTotal}MB"
@@ -668,7 +579,7 @@ class GPUTools:
         Returns:
             float: _GPU Temperature_
         """
-        if (PSTValidators.BooleanValidator.is_boolean(show)):
+        if (BooleanValidator.is_boolean(show)):
             if (show is True):
                 for gpu in cls.gpuInfo:
                     gpuTemp = f"{gpu.temperature}℃"
@@ -690,7 +601,7 @@ class GPUTools:
         Returns:
             str: _GPU UUID_
         """
-        if (PSTValidators.BooleanValidator.is_boolean(show)):
+        if (BooleanValidator.is_boolean(show)):
             if (show is True):
                 for gpu in cls.gpuInfo:
                     gpuUUID = gpu.uuid
@@ -720,9 +631,9 @@ class RAMTools:
         Returns:
             float: _Total RAM Memory_
         """
-        if (PSTValidators.BooleanValidator.is_boolean(show)):
+        if (BooleanValidator.is_boolean(show)):
             if (show is True):
-                return f"{PSTValidators.LengthValidator.getSize(cls.ramVir.total)}"
+                return f"{LengthValidator.getSize(cls.ramVir.total)}"
             elif (show is False):
                 return AdminPermissionRequestDenied
             else:
@@ -740,9 +651,9 @@ class RAMTools:
         Returns:
             float: _Available RAM Memory_
         """
-        if (PSTValidators.BooleanValidator.is_boolean(show)):
+        if (BooleanValidator.is_boolean(show)):
             if (show is True):
-                return f"{PSTValidators.LengthValidator.getSize(cls.ramVir.available)}"
+                return f"{LengthValidator.getSize(cls.ramVir.available)}"
             elif (show is False):
                 return AdminPermissionRequestDenied
             else:
@@ -760,9 +671,9 @@ class RAMTools:
         Returns:
             float: _Used RAM Memory_
         """
-        if (PSTValidators.BooleanValidator.is_boolean(show)):
+        if (BooleanValidator.is_boolean(show)):
             if (show is True):
-                return f"{PSTValidators.LengthValidator.getSize(cls.ramVir.used)}"
+                return f"{LengthValidator.getSize(cls.ramVir.used)}"
             elif (show is False):
                 return AdminPermissionRequestDenied
             else:
@@ -780,9 +691,9 @@ class RAMTools:
         Returns:
             float: _RAM Percentage_
         """
-        if (PSTValidators.BooleanValidator.is_boolean(show)):
+        if (BooleanValidator.is_boolean(show)):
             if (show is True):
-                return f"{PSTValidators.LengthValidator.getSize(cls.ramVir.percent)}%"
+                return f"{LengthValidator.getSize(cls.ramVir.percent)}%"
             elif (show is False):
                 return AdminPermissionRequestDenied
             else:
@@ -800,9 +711,9 @@ class RAMTools:
         Returns:
             float: _Total Swap Memory_
         """
-        if (PSTValidators.BooleanValidator.is_boolean(show)):
+        if (BooleanValidator.is_boolean(show)):
             if (show is True):
-                return f"{PSTValidators.LengthValidator.getSize(cls.swapMemo.total)}"
+                return f"{LengthValidator.getSize(cls.swapMemo.total)}"
             elif (show is False):
                 return AdminPermissionRequestDenied
             else:
@@ -820,9 +731,9 @@ class RAMTools:
         Returns:
             int: _Free Swap Memory_
         """
-        if (PSTValidators.BooleanValidator.is_boolean(show)):
+        if (BooleanValidator.is_boolean(show)):
             if (show is True):
-                return f"{PSTValidators.LengthValidator.getSize(cls.swapMemo.free)}"
+                return f"{LengthValidator.getSize(cls.swapMemo.free)}"
             elif (show is False):
                 return AdminPermissionRequestDenied
             else:
@@ -840,9 +751,9 @@ class RAMTools:
         Returns:
             float: _Used Swap Memory_
         """
-        if (PSTValidators.BooleanValidator.is_boolean(show)):
+        if (BooleanValidator.is_boolean(show)):
             if (show is True):
-                return f"{PSTValidators.LengthValidator.getSize(cls.swapMemo.used)}"
+                return f"{LengthValidator.getSize(cls.swapMemo.used)}"
             elif (show is False):
                 return AdminPermissionRequestDenied
             else:
@@ -860,9 +771,9 @@ class RAMTools:
         Returns:
             float: _Swap Percentage_
         """
-        if (PSTValidators.BooleanValidator.is_boolean(show)):
+        if (BooleanValidator.is_boolean(show)):
             if (show is True):
-                return f"{PSTValidators.LengthValidator.getSize(cls.swapMemo.percent)}%"
+                return f"{LengthValidator.getSize(cls.swapMemo.percent)}%"
             elif (show is False):
                 return AdminPermissionRequestDenied
             else:
@@ -891,7 +802,7 @@ class DiskTools:
         Returns:
             list: _List Of All Available Drives_
         """
-        if (PSTValidators.BooleanValidator.is_boolean(show)):
+        if (BooleanValidator.is_boolean(show)):
             if (show is True):
                 for driver in string.ascii_uppercase:
                     if (cls.bitMask & 1) :
@@ -915,7 +826,7 @@ class DiskTools:
         Returns:
             list: _Parent Disk Total Memory_
         """
-        if (PSTValidators.BooleanValidator.is_boolean(show)):
+        if (BooleanValidator.is_boolean(show)):
             if (show is True):
                 return cls.parentDiskInfo.total / 1024 ** 3
             elif (show is False):
@@ -935,7 +846,7 @@ class DiskTools:
         Returns:
             list: _Parent Disk Used Memory_
         """
-        if (PSTValidators.BooleanValidator.is_boolean(show)):
+        if (BooleanValidator.is_boolean(show)):
             if (show is True):
                 return cls.parentDiskInfo.used / 1024 ** 3
             elif (show is False):
@@ -955,7 +866,7 @@ class DiskTools:
         Returns:
             list: _Parent Disk Free Memory_
         """
-        if (PSTValidators.BooleanValidator.is_boolean(show)):
+        if (BooleanValidator.is_boolean(show)):
             if (show is True):
                 return cls.parentDiskInfo.free / 1024 ** 3
             elif (show is False):
@@ -975,7 +886,7 @@ class DiskTools:
         Returns:
             list: _Parent Disk Percentage_
         """
-        if (PSTValidators.BooleanValidator.is_boolean(show)):
+        if (BooleanValidator.is_boolean(show)):
             if (show is True):
                 return f"{cls.parentDiskInfo.percent:.2f}"
             elif (show is False):
@@ -995,7 +906,7 @@ class DiskTools:
         Returns:
             list: _Disk Information_
         """
-        if (PSTValidators.BooleanValidator.is_boolean(show)):
+        if (BooleanValidator.is_boolean(show)):
             if (show is True):
                 for partition in cls.drivesInfo:
                     print(f"{colorama.ansi.Fore.GREEN}=== Device : {partition.device} ===")
@@ -1005,10 +916,10 @@ class DiskTools:
                         partitionUsage = psutil.disk_usage(partition.mountpoint)
                     except PermissionError:
                         continue
-                    print(f"Total Size : {PSTValidators.LengthValidator.getSize(partitionUsage.total)}")
-                    print(f"Used : {PSTValidators.LengthValidator.getSize(partitionUsage.used)}")
-                    print(f"Free : {PSTValidators.LengthValidator.getSize(partitionUsage.free)}")
-                    print(f"Percentage : {PSTValidators.LengthValidator.getSize(partitionUsage.percent)}\n")
+                    print(f"Total Size : {LengthValidator.getSize(partitionUsage.total)}")
+                    print(f"Used : {LengthValidator.getSize(partitionUsage.used)}")
+                    print(f"Free : {LengthValidator.getSize(partitionUsage.free)}")
+                    print(f"Percentage : {LengthValidator.getSize(partitionUsage.percent)}\n")
             elif (show is False):
                 return AdminPermissionRequestDenied
             else:
@@ -1049,7 +960,7 @@ class SystemTools:
         Returns:
             str: _Operating System's Name_
         """
-        if (PSTValidators.BooleanValidator.is_boolean(show)):
+        if (BooleanValidator.is_boolean(show)):
             if (show is True):
                 return cls.osName
             elif (show is False):
@@ -1069,7 +980,7 @@ class SystemTools:
         Returns:
             str: _Operating System's Type
         """
-        if (PSTValidators.BooleanValidator.is_boolean(show)):
+        if (BooleanValidator.is_boolean(show)):
             if (show is True):
                 return cls.osType
             elif (show is False):
@@ -1089,7 +1000,7 @@ class SystemTools:
         Returns:
             str: _Node Name or System's Name_
         """
-        if (PSTValidators.BooleanValidator.is_boolean(show)):
+        if (BooleanValidator.is_boolean(show)):
             if (show is True):
                 return cls.nodeName
             elif (show is False):
@@ -1109,7 +1020,7 @@ class SystemTools:
         Returns:
             str: _Operating System's Release_
         """
-        if (PSTValidators.BooleanValidator.is_boolean(show)):
+        if (BooleanValidator.is_boolean(show)):
             if (show is True):
                 return cls.sysRelease
             elif (show is False):
@@ -1129,7 +1040,7 @@ class SystemTools:
         Returns:
             str: _Operating System's Version_
         """
-        if (PSTValidators.BooleanValidator.is_boolean(show)):
+        if (BooleanValidator.is_boolean(show)):
             if (show is True):
                 return cls.sysVersion
             elif (show is False):
@@ -1149,7 +1060,7 @@ class SystemTools:
         Returns:
             str: _System's Name_
         """
-        if (PSTValidators.BooleanValidator.is_boolean(show)):
+        if (BooleanValidator.is_boolean(show)):
             if (show is True):
                 return cls.systemName
             elif (show is False):
@@ -1169,7 +1080,7 @@ class SystemTools:
         Returns:
             str: _System's Uptime_
         """
-        if (PSTValidators.BooleanValidator.is_boolean(show)):
+        if (BooleanValidator.is_boolean(show)):
             if (show is True):
                 return cls.uptimeSystem
             elif (show is False):
@@ -1189,7 +1100,7 @@ class SystemTools:
         Returns:
             str: _Active Logined Username_
         """
-        if (PSTValidators.BooleanValidator.is_boolean(show)):
+        if (BooleanValidator.is_boolean(show)):
             if (show is True):
                 return cls.userName
             elif (show is False):
@@ -1210,10 +1121,10 @@ class SystemTools:
         Returns:
             str: _Shows System Information Based On Your Operating System_
         """
-        if (PSTValidators.BooleanValidator.is_boolean(show)):
+        if (BooleanValidator.is_boolean(show)):
             if (show is True):
-                if (PSTValidators.StringValidator.is_string(os_name)):
-                    if (PSTValidators.WindowsOperatingSystemIdentifierValidator.is_windows(os_name)):
+                if (StringValidator.is_string(os_name)):
+                    if (WindowsOperatingSystemIdentifierValidator.is_windows(os_name)):
                         print (
                             f"{colorama.ansi.Fore.GREEN}OS Name : {colorama.ansi.Fore.BLUE}{cls.osName}" ,
                             f"\n{colorama.ansi.Fore.GREEN}OS Type : {colorama.ansi.Fore.WHITE}{cls.osType}" ,
@@ -1223,7 +1134,7 @@ class SystemTools:
                             f"\n{colorama.ansi.Fore.GREEN}System Uptime : {colorama.ansi.Fore.WHITE}{cls.uptimeSystem}" ,
                             f"\n{colorama.ansi.Fore.GREEN}User Logined As : {colorama.ansi.Fore.WHITE}{cls.userName}"
                         )
-                    elif (PSTValidators.LinuxOperatingSystemIdentifierValidator.is_linux(os_name)):
+                    elif (LinuxOperatingSystemIdentifierValidator.is_linux(os_name)):
                         print (
                             f"{colorama.ansi.Fore.GREEN}OS Name : {colorama.ansi.Fore.BLUE}{cls.osName}" ,
                             f"\n{colorama.ansi.Fore.GREEN}OS Type : {colorama.ansi.Fore.WHITE}{cls.osType}" ,
@@ -1254,7 +1165,7 @@ class SystemTools:
         Returns:
             str: _Python Version_
         """
-        if (PSTValidators.BooleanValidator.is_boolean(show)):
+        if (BooleanValidator.is_boolean(show)):
             if (show is True):
                 return cls.pythonVer
             elif (show is False):
@@ -1274,7 +1185,7 @@ class SystemTools:
         Returns:
             str: _Operating System's Boot Time_
         """
-        if (PSTValidators.BooleanValidator.is_boolean(show)):
+        if (BooleanValidator.is_boolean(show)):
             if (show is True):
                 return cls.bootTime
             elif (show is False):
@@ -1306,9 +1217,9 @@ class OtherTools:
         Returns:
             str: _Customized Ascii Art_
         """
-        if (PSTValidators.BooleanValidator.is_boolean(show)):
+        if (BooleanValidator.is_boolean(show)):
             if (show is True):
-                if (PSTValidators.StringValidator.is_string([text , font])):
+                if (StringValidator.is_string([text , font])):
                     cls.text = str(text)
                     cls.colors = colors
                     cls.align = align
@@ -1338,9 +1249,9 @@ class OtherTools:
         Returns:
             str: _Validates The Path You've Entered_
         """
-        if (PSTValidators.BooleanValidator.is_boolean(show)):
+        if (BooleanValidator.is_boolean(show)):
             if (show is True):
-                if (PSTValidators.StringValidator.is_string(pathaddr)):
+                if (StringValidator.is_string(pathaddr)):
                     if (os.path.exists(r"{0}".format(pathaddr)) and (platform.system()[0].upper() in ["W" , "L" , "J"])):
                         return f"{colorama.ansi.Fore.GREEN}The Path Exists\nThe Code Output is {colorama.ansi.Fore.BLUE}{True}"
                     else:
@@ -1365,9 +1276,9 @@ class OtherTools:
         Returns:
             str: _Runs The Text as a Python Command or Expression_
         """
-        if (PSTValidators.BooleanValidator.is_boolean(show)):
+        if (BooleanValidator.is_boolean(show)):
             if (show is True):
-                if (PSTValidators.StringValidator.is_string(string)):
+                if (StringValidator.is_string(string)):
                     return eval(string)
                 else:
                     return InvalidVariableType
